# AMONG-py
This project is a python part of AMONG project

## version 0.0.1
* visualization.result_chart_js : json output for chart.js

## version 0.0.1.2
* analysis.get_recommended_project : json output for recommended project(very simple way)

## version 0.0.2
* input adjusted for exam_logs

## version 0.0.3
* .py files are moved to AMONGpy directory

## version 0.0.3.1
* visualization.result_chart_js : chart is always drawed with range 0~100

## version 0.0.3.2
* visualization.result_chart_js : answer num bug is fixed

## version 0.0.3.4
* same as previous version
